==> openshift-model-operatorhub-5.11.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class InstallPlanSpecFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<A>{
  public InstallPlanSpecFluentImpl() {
  }
  public InstallPlanSpecFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance) {
    this.withApproval(instance.getApproval()); 
    this.withApproved(instance.getApproved()); 
    this.withClusterServiceVersionNames(instance.getClusterServiceVersionNames()); 
    this.withGeneration(instance.getGeneration()); 
    this.withSource(instance.getSource()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String approval;
  private java.lang.Boolean approved;
  private java.util.List<java.lang.String> clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();
  private java.lang.Integer generation;
  private java.lang.String source;
  private java.lang.String sourceNamespace;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApproval() {
    return this.approval;
  }
  public A withApproval(java.lang.String approval) {
    this.approval=approval; return (A) this;
  }
  public java.lang.Boolean hasApproval() {
    return this.approval != null;
  }
  
  /**
   * Method is deprecated. use withApproval instead.
   */
  @java.lang.Deprecated
  public A withNewApproval(java.lang.String arg0) {
    return (A)withApproval(new String(arg0));
  }
  public java.lang.Boolean getApproved() {
    return this.approved;
  }
  public A withApproved(java.lang.Boolean approved) {
    this.approved=approved; return (A) this;
  }
  public java.lang.Boolean hasApproved() {
    return this.approved != null;
  }
  public A addToClusterServiceVersionNames(java.lang.Integer index,java.lang.String item) {
    if (this.clusterServiceVersionNames == null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();}
    this.clusterServiceVersionNames.add(index, item);
    return (A)this;
  }
  public A setToClusterServiceVersionNames(java.lang.Integer index,java.lang.String item) {
    if (this.clusterServiceVersionNames == null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();}
    this.clusterServiceVersionNames.set(index, item); return (A)this;
  }
  public A addToClusterServiceVersionNames(java.lang.String... items) {
    if (this.clusterServiceVersionNames == null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.clusterServiceVersionNames.add(item);} return (A)this;
  }
  public A addAllToClusterServiceVersionNames(java.util.Collection<java.lang.String> items) {
    if (this.clusterServiceVersionNames == null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.clusterServiceVersionNames.add(item);} return (A)this;
  }
  public A removeFromClusterServiceVersionNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.clusterServiceVersionNames!= null){ this.clusterServiceVersionNames.remove(item);}} return (A)this;
  }
  public A removeAllFromClusterServiceVersionNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.clusterServiceVersionNames!= null){ this.clusterServiceVersionNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getClusterServiceVersionNames() {
    return this.clusterServiceVersionNames;
  }
  public java.lang.String getClusterServiceVersionName(java.lang.Integer index) {
    return this.clusterServiceVersionNames.get(index);
  }
  public java.lang.String getFirstClusterServiceVersionName() {
    return this.clusterServiceVersionNames.get(0);
  }
  public java.lang.String getLastClusterServiceVersionName() {
    return this.clusterServiceVersionNames.get(clusterServiceVersionNames.size() - 1);
  }
  public java.lang.String getMatchingClusterServiceVersionName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: clusterServiceVersionNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingClusterServiceVersionName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: clusterServiceVersionNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withClusterServiceVersionNames(java.util.List<java.lang.String> clusterServiceVersionNames) {
    if (clusterServiceVersionNames != null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : clusterServiceVersionNames){this.addToClusterServiceVersionNames(item);}} else { this.clusterServiceVersionNames = null;} return (A) this;
  }
  public A withClusterServiceVersionNames(java.lang.String... clusterServiceVersionNames) {
    if (this.clusterServiceVersionNames != null) {this.clusterServiceVersionNames.clear();}
    if (clusterServiceVersionNames != null) {for (java.lang.String item :clusterServiceVersionNames){ this.addToClusterServiceVersionNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasClusterServiceVersionNames() {
    return clusterServiceVersionNames != null && !clusterServiceVersionNames.isEmpty();
  }
  public A addNewClusterServiceVersionName(java.lang.String arg0) {
    return (A)addToClusterServiceVersionNames(new String(arg0));
  }
  public java.lang.Integer getGeneration() {
    return this.generation;
  }
  public A withGeneration(java.lang.Integer generation) {
    this.generation=generation; return (A) this;
  }
  public java.lang.Boolean hasGeneration() {
    return this.generation != null;
  }
  public java.lang.String getSource() {
    return this.source;
  }
  public A withSource(java.lang.String source) {
    this.source=source; return (A) this;
  }
  public java.lang.Boolean hasSource() {
    return this.source != null;
  }
  
  /**
   * Method is deprecated. use withSource instead.
   */
  @java.lang.Deprecated
  public A withNewSource(java.lang.String arg0) {
    return (A)withSource(new String(arg0));
  }
  public java.lang.String getSourceNamespace() {
    return this.sourceNamespace;
  }
  public A withSourceNamespace(java.lang.String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  public java.lang.Boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  /**
   * Method is deprecated. use withSourceNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewSourceNamespace(java.lang.String arg0) {
    return (A)withSourceNamespace(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    InstallPlanSpecFluentImpl that = (InstallPlanSpecFluentImpl) o;
    if (approval != null ? !approval.equals(that.approval) :that.approval != null) return false;
    if (approved != null ? !approved.equals(that.approved) :that.approved != null) return false;
    if (clusterServiceVersionNames != null ? !clusterServiceVersionNames.equals(that.clusterServiceVersionNames) :that.clusterServiceVersionNames != null) return false;
    if (generation != null ? !generation.equals(that.generation) :that.generation != null) return false;
    if (source != null ? !source.equals(that.source) :that.source != null) return false;
    if (sourceNamespace != null ? !sourceNamespace.equals(that.sourceNamespace) :that.sourceNamespace != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(approval,  approved,  clusterServiceVersionNames,  generation,  source,  sourceNamespace,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/InstallPlanSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class InstallPlanSpecFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpecFluent<A>{
  public InstallPlanSpecFluentImpl() {
  }
  public InstallPlanSpecFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.InstallPlanSpec instance) {
    this.withApproval(instance.getApproval()); 
    this.withApproved(instance.getApproved()); 
    this.withClusterServiceVersionNames(instance.getClusterServiceVersionNames()); 
    this.withGeneration(instance.getGeneration()); 
    this.withSource(instance.getSource()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String approval;
  private java.lang.Boolean approved;
  private java.util.List<java.lang.String> clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();
  private java.lang.Integer generation;
  private java.lang.String source;
  private java.lang.String sourceNamespace;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApproval() {
    return this.approval;
  }
  public A withApproval(java.lang.String approval) {
    this.approval=approval; return (A) this;
  }
  public java.lang.Boolean hasApproval() {
    return this.approval != null;
  }
  
  /**
   * Method is deprecated. use withApproval instead.
   */
  @java.lang.Deprecated
  public A withNewApproval(java.lang.String arg0) {
    return (A)withApproval(new String(arg0));
  }
  public java.lang.Boolean getApproved() {
    return this.approved;
  }
  public A withApproved(java.lang.Boolean approved) {
    this.approved=approved; return (A) this;
  }
  public java.lang.Boolean hasApproved() {
    return this.approved != null;
  }
  public A addToClusterServiceVersionNames(java.lang.Integer index,java.lang.String item) {
    if (this.clusterServiceVersionNames == null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();}
    this.clusterServiceVersionNames.add(index, item);
    return (A)this;
  }
  public A setToClusterServiceVersionNames(java.lang.Integer index,java.lang.String item) {
    if (this.clusterServiceVersionNames == null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();}
    this.clusterServiceVersionNames.set(index, item); return (A)this;
  }
  public A addToClusterServiceVersionNames(java.lang.String... items) {
    if (this.clusterServiceVersionNames == null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.clusterServiceVersionNames.add(item);} return (A)this;
  }
  public A addAllToClusterServiceVersionNames(java.util.Collection<java.lang.String> items) {
    if (this.clusterServiceVersionNames == null) {this.clusterServiceVersionNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.clusterServiceVersionNames.add(item);} return (A)this;
  }
  public A removeFromClusterServiceVersionNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.clusterServiceVersionNames!= null){ this.clusterServiceVersionNames.remove(item);}} return (A)this;
  }
  public A removeAllFromClusterServiceVersionNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.clusterServiceVersionNames!= null){ this.clusterServiceVersionNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getClusterServiceVersionNames() {
    return this.clusterServiceVersionNames;
  }
  public java.lang.String getClusterServiceVersionName(java.lang.Integer index) {
    return this.clusterServiceVersionNames.get(index);
  }
  public java.lang.String getFirstClusterServiceVersionName() {
    return this.clusterServiceVersionNames.get(0);
  }
  public java.lang.String getLastClusterServiceVersionName() {
    return this.clusterServiceVersionNames.get(clusterServiceVersionNames.size() - 1);
  }
  public java.lang.String getMatchingClusterServiceVersionName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: clusterServiceVersionNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingClusterServiceVersionName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: clusterServiceVersionNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withClusterServiceVersionNames(java.util.List<java.lang.String> clusterServiceVersionNames) {
    if (clusterServiceVersionNames != null) {this.clusterServiceVersionNames = new java.util.ArrayList(); for (java.lang.String item : clusterServiceVersionNames){this.addToClusterServiceVersionNames(item);}} else { this.clusterServiceVersionNames = null;} return (A) this;
  }
  public A withClusterServiceVersionNames(java.lang.String... clusterServiceVersionNames) {
    if (this.clusterServiceVersionNames != null) {this.clusterServiceVersionNames.clear();}
    if (clusterServiceVersionNames != null) {for (java.lang.String item :clusterServiceVersionNames){ this.addToClusterServiceVersionNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasClusterServiceVersionNames() {
    return clusterServiceVersionNames != null && !clusterServiceVersionNames.isEmpty();
  }
  public A addNewClusterServiceVersionName(java.lang.String arg0) {
    return (A)addToClusterServiceVersionNames(new String(arg0));
  }
  public java.lang.Integer getGeneration() {
    return this.generation;
  }
  public A withGeneration(java.lang.Integer generation) {
    this.generation=generation; return (A) this;
  }
  public java.lang.Boolean hasGeneration() {
    return this.generation != null;
  }
  public java.lang.String getSource() {
    return this.source;
  }
  public A withSource(java.lang.String source) {
    this.source=source; return (A) this;
  }
  public java.lang.Boolean hasSource() {
    return this.source != null;
  }
  
  /**
   * Method is deprecated. use withSource instead.
   */
  @java.lang.Deprecated
  public A withNewSource(java.lang.String arg0) {
    return (A)withSource(new String(arg0));
  }
  public java.lang.String getSourceNamespace() {
    return this.sourceNamespace;
  }
  public A withSourceNamespace(java.lang.String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  public java.lang.Boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  /**
   * Method is deprecated. use withSourceNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewSourceNamespace(java.lang.String arg0) {
    return (A)withSourceNamespace(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    InstallPlanSpecFluentImpl that = (InstallPlanSpecFluentImpl) o;
    if (approval != null ? !approval.equals(that.approval) :that.approval != null) return false;
    if (approved != null ? !approved.equals(that.approved) :that.approved != null) return false;
    if (clusterServiceVersionNames != null ? !clusterServiceVersionNames.equals(that.clusterServiceVersionNames) :that.clusterServiceVersionNames != null) return false;
    if (generation != null ? !generation.equals(that.generation) :that.generation != null) return false;
    if (source != null ? !source.equals(that.source) :that.source != null) return false;
    if (sourceNamespace != null ? !sourceNamespace.equals(that.sourceNamespace) :that.sourceNamespace != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(approval,  approved,  clusterServiceVersionNames,  generation,  source,  sourceNamespace,  additionalProperties,  super.hashCode());
  }
  
}
